# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LastBlock(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chain': 'str',
        'last_observed_in': 'int',
        'last_signed_out': 'int',
        'mayachain': 'int'
    }

    attribute_map = {
        'chain': 'chain',
        'last_observed_in': 'last_observed_in',
        'last_signed_out': 'last_signed_out',
        'mayachain': 'mayachain'
    }

    def __init__(self, chain=None, last_observed_in=None, last_signed_out=None, mayachain=None):  # noqa: E501
        """LastBlock - a model defined in Swagger"""  # noqa: E501
        self._chain = None
        self._last_observed_in = None
        self._last_signed_out = None
        self._mayachain = None
        self.discriminator = None
        self.chain = chain
        self.last_observed_in = last_observed_in
        self.last_signed_out = last_signed_out
        self.mayachain = mayachain

    @property
    def chain(self):
        """Gets the chain of this LastBlock.  # noqa: E501


        :return: The chain of this LastBlock.  # noqa: E501
        :rtype: str
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this LastBlock.


        :param chain: The chain of this LastBlock.  # noqa: E501
        :type: str
        """
        if chain is None:
            raise ValueError("Invalid value for `chain`, must not be `None`")  # noqa: E501

        self._chain = chain

    @property
    def last_observed_in(self):
        """Gets the last_observed_in of this LastBlock.  # noqa: E501


        :return: The last_observed_in of this LastBlock.  # noqa: E501
        :rtype: int
        """
        return self._last_observed_in

    @last_observed_in.setter
    def last_observed_in(self, last_observed_in):
        """Sets the last_observed_in of this LastBlock.


        :param last_observed_in: The last_observed_in of this LastBlock.  # noqa: E501
        :type: int
        """
        if last_observed_in is None:
            raise ValueError("Invalid value for `last_observed_in`, must not be `None`")  # noqa: E501

        self._last_observed_in = last_observed_in

    @property
    def last_signed_out(self):
        """Gets the last_signed_out of this LastBlock.  # noqa: E501


        :return: The last_signed_out of this LastBlock.  # noqa: E501
        :rtype: int
        """
        return self._last_signed_out

    @last_signed_out.setter
    def last_signed_out(self, last_signed_out):
        """Sets the last_signed_out of this LastBlock.


        :param last_signed_out: The last_signed_out of this LastBlock.  # noqa: E501
        :type: int
        """
        if last_signed_out is None:
            raise ValueError("Invalid value for `last_signed_out`, must not be `None`")  # noqa: E501

        self._last_signed_out = last_signed_out

    @property
    def mayachain(self):
        """Gets the mayachain of this LastBlock.  # noqa: E501


        :return: The mayachain of this LastBlock.  # noqa: E501
        :rtype: int
        """
        return self._mayachain

    @mayachain.setter
    def mayachain(self, mayachain):
        """Sets the mayachain of this LastBlock.


        :param mayachain: The mayachain of this LastBlock.  # noqa: E501
        :type: int
        """
        if mayachain is None:
            raise ValueError("Invalid value for `mayachain`, must not be `None`")  # noqa: E501

        self._mayachain = mayachain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LastBlock, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LastBlock):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from xchainpy2_mayanode.api_client import ApiClient


class QuoteApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def quotesaverdeposit(self, **kwargs):  # noqa: E501
        """quotesaverdeposit  # noqa: E501

        Provide a quote estimate for the provided saver deposit.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.quotesaverdeposit(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :param str asset: the asset to deposit
        :param int amount: the source asset amount in 1e8 decimals
        :return: QuoteSaverDepositResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.quotesaverdeposit_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.quotesaverdeposit_with_http_info(**kwargs)  # noqa: E501
            return data

    def quotesaverdeposit_with_http_info(self, **kwargs):  # noqa: E501
        """quotesaverdeposit  # noqa: E501

        Provide a quote estimate for the provided saver deposit.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.quotesaverdeposit_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :param str asset: the asset to deposit
        :param int amount: the source asset amount in 1e8 decimals
        :return: QuoteSaverDepositResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height', 'asset', 'amount']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method quotesaverdeposit" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501
        if 'asset' in params:
            query_params.append(('asset', params['asset']))  # noqa: E501
        if 'amount' in params:
            query_params.append(('amount', params['amount']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/mayachain/quote/saver/deposit', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QuoteSaverDepositResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def quotesaverwithdraw(self, **kwargs):  # noqa: E501
        """quotesaverwithdraw  # noqa: E501

        Provide a quote estimate for the provided saver withdraw.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.quotesaverwithdraw(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :param str asset: the asset to withdraw
        :param str address: the address for the position
        :param int withdraw_bps: the basis points of the existing position to withdraw
        :return: QuoteSaverWithdrawResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.quotesaverwithdraw_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.quotesaverwithdraw_with_http_info(**kwargs)  # noqa: E501
            return data

    def quotesaverwithdraw_with_http_info(self, **kwargs):  # noqa: E501
        """quotesaverwithdraw  # noqa: E501

        Provide a quote estimate for the provided saver withdraw.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.quotesaverwithdraw_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :param str asset: the asset to withdraw
        :param str address: the address for the position
        :param int withdraw_bps: the basis points of the existing position to withdraw
        :return: QuoteSaverWithdrawResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height', 'asset', 'address', 'withdraw_bps']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method quotesaverwithdraw" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501
        if 'asset' in params:
            query_params.append(('asset', params['asset']))  # noqa: E501
        if 'address' in params:
            query_params.append(('address', params['address']))  # noqa: E501
        if 'withdraw_bps' in params:
            query_params.append(('withdraw_bps', params['withdraw_bps']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/mayachain/quote/saver/withdraw', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QuoteSaverWithdrawResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def quoteswap(self, **kwargs):  # noqa: E501
        """quoteswap  # noqa: E501

        Provide a quote estimate for the provided swap.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.quoteswap(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :param str from_asset: the source asset
        :param str to_asset: the target asset
        :param int amount: the source asset amount in 1e8 decimals
        :param str destination: the destination address, required to generate memo
        :param str from_address: the from address, required if the from asset is a synth
        :param int tolerance_bps: the maximum basis points from the current feeless swap price to set the limit in the generated memo
        :param int affiliate_bps: the affiliate fee in basis points
        :param str affiliate: the affiliate (address or mayaname)
        :return: QuoteSwapResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.quoteswap_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.quoteswap_with_http_info(**kwargs)  # noqa: E501
            return data

    def quoteswap_with_http_info(self, **kwargs):  # noqa: E501
        """quoteswap  # noqa: E501

        Provide a quote estimate for the provided swap.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.quoteswap_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :param str from_asset: the source asset
        :param str to_asset: the target asset
        :param int amount: the source asset amount in 1e8 decimals
        :param str destination: the destination address, required to generate memo
        :param str from_address: the from address, required if the from asset is a synth
        :param int tolerance_bps: the maximum basis points from the current feeless swap price to set the limit in the generated memo
        :param int affiliate_bps: the affiliate fee in basis points
        :param str affiliate: the affiliate (address or mayaname)
        :return: QuoteSwapResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height', 'from_asset', 'to_asset', 'amount', 'destination', 'from_address', 'tolerance_bps', 'affiliate_bps', 'affiliate']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method quoteswap" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501
        if 'from_asset' in params:
            query_params.append(('from_asset', params['from_asset']))  # noqa: E501
        if 'to_asset' in params:
            query_params.append(('to_asset', params['to_asset']))  # noqa: E501
        if 'amount' in params:
            query_params.append(('amount', params['amount']))  # noqa: E501
        if 'destination' in params:
            query_params.append(('destination', params['destination']))  # noqa: E501
        if 'from_address' in params:
            query_params.append(('from_address', params['from_address']))  # noqa: E501
        if 'tolerance_bps' in params:
            query_params.append(('tolerance_bps', params['tolerance_bps']))  # noqa: E501
        if 'affiliate_bps' in params:
            query_params.append(('affiliate_bps', params['affiliate_bps']))  # noqa: E501
        if 'affiliate' in params:
            query_params.append(('affiliate', params['affiliate']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/mayachain/quote/swap', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QuoteSwapResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class QuoteFees(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'str',
        'affiliate': 'str',
        'outbound': 'str'
    }

    attribute_map = {
        'asset': 'asset',
        'affiliate': 'affiliate',
        'outbound': 'outbound'
    }

    def __init__(self, asset=None, affiliate=None, outbound=None):  # noqa: E501
        """QuoteFees - a model defined in Swagger"""  # noqa: E501
        self._asset = None
        self._affiliate = None
        self._outbound = None
        self.discriminator = None
        self.asset = asset
        self.affiliate = affiliate
        self.outbound = outbound

    @property
    def asset(self):
        """Gets the asset of this QuoteFees.  # noqa: E501


        :return: The asset of this QuoteFees.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this QuoteFees.


        :param asset: The asset of this QuoteFees.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def affiliate(self):
        """Gets the affiliate of this QuoteFees.  # noqa: E501


        :return: The affiliate of this QuoteFees.  # noqa: E501
        :rtype: str
        """
        return self._affiliate

    @affiliate.setter
    def affiliate(self, affiliate):
        """Sets the affiliate of this QuoteFees.


        :param affiliate: The affiliate of this QuoteFees.  # noqa: E501
        :type: str
        """
        if affiliate is None:
            raise ValueError("Invalid value for `affiliate`, must not be `None`")  # noqa: E501

        self._affiliate = affiliate

    @property
    def outbound(self):
        """Gets the outbound of this QuoteFees.  # noqa: E501


        :return: The outbound of this QuoteFees.  # noqa: E501
        :rtype: str
        """
        return self._outbound

    @outbound.setter
    def outbound(self, outbound):
        """Sets the outbound of this QuoteFees.


        :param outbound: The outbound of this QuoteFees.  # noqa: E501
        :type: str
        """
        if outbound is None:
            raise ValueError("Invalid value for `outbound`, must not be `None`")  # noqa: E501

        self._outbound = outbound

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QuoteFees, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuoteFees):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Tx(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'chain': 'str',
        'from_address': 'str',
        'to_address': 'str',
        'coins': 'list[Coin]',
        'gas': 'list[Coin]',
        'memo': 'str'
    }

    attribute_map = {
        'id': 'id',
        'chain': 'chain',
        'from_address': 'from_address',
        'to_address': 'to_address',
        'coins': 'coins',
        'gas': 'gas',
        'memo': 'memo'
    }

    def __init__(self, id=None, chain=None, from_address=None, to_address=None, coins=None, gas=None, memo=None):  # noqa: E501
        """Tx - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._chain = None
        self._from_address = None
        self._to_address = None
        self._coins = None
        self._gas = None
        self._memo = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if chain is not None:
            self.chain = chain
        if from_address is not None:
            self.from_address = from_address
        if to_address is not None:
            self.to_address = to_address
        self.coins = coins
        self.gas = gas
        if memo is not None:
            self.memo = memo

    @property
    def id(self):
        """Gets the id of this Tx.  # noqa: E501


        :return: The id of this Tx.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Tx.


        :param id: The id of this Tx.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def chain(self):
        """Gets the chain of this Tx.  # noqa: E501


        :return: The chain of this Tx.  # noqa: E501
        :rtype: str
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this Tx.


        :param chain: The chain of this Tx.  # noqa: E501
        :type: str
        """

        self._chain = chain

    @property
    def from_address(self):
        """Gets the from_address of this Tx.  # noqa: E501


        :return: The from_address of this Tx.  # noqa: E501
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """Sets the from_address of this Tx.


        :param from_address: The from_address of this Tx.  # noqa: E501
        :type: str
        """

        self._from_address = from_address

    @property
    def to_address(self):
        """Gets the to_address of this Tx.  # noqa: E501


        :return: The to_address of this Tx.  # noqa: E501
        :rtype: str
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """Sets the to_address of this Tx.


        :param to_address: The to_address of this Tx.  # noqa: E501
        :type: str
        """

        self._to_address = to_address

    @property
    def coins(self):
        """Gets the coins of this Tx.  # noqa: E501


        :return: The coins of this Tx.  # noqa: E501
        :rtype: list[Coin]
        """
        return self._coins

    @coins.setter
    def coins(self, coins):
        """Sets the coins of this Tx.


        :param coins: The coins of this Tx.  # noqa: E501
        :type: list[Coin]
        """
        if coins is None:
            raise ValueError("Invalid value for `coins`, must not be `None`")  # noqa: E501

        self._coins = coins

    @property
    def gas(self):
        """Gets the gas of this Tx.  # noqa: E501


        :return: The gas of this Tx.  # noqa: E501
        :rtype: list[Coin]
        """
        return self._gas

    @gas.setter
    def gas(self, gas):
        """Sets the gas of this Tx.


        :param gas: The gas of this Tx.  # noqa: E501
        :type: list[Coin]
        """
        if gas is None:
            raise ValueError("Invalid value for `gas`, must not be `None`")  # noqa: E501

        self._gas = gas

    @property
    def memo(self):
        """Gets the memo of this Tx.  # noqa: E501


        :return: The memo of this Tx.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this Tx.


        :param memo: The memo of this Tx.  # noqa: E501
        :type: str
        """

        self._memo = memo

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Tx, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Tx):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NetworkResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bond_reward_rune': 'str',
        'total_bond_units': 'str',
        'total_reserve': 'str',
        'total_asgard': 'str',
        'gas_spent_cacao': 'str',
        'gas_withheld_cacao': 'str',
        'outbound_fee_multiplier': 'str'
    }

    attribute_map = {
        'bond_reward_rune': 'bond_reward_rune',
        'total_bond_units': 'total_bond_units',
        'total_reserve': 'total_reserve',
        'total_asgard': 'total_asgard',
        'gas_spent_cacao': 'gas_spent_cacao',
        'gas_withheld_cacao': 'gas_withheld_cacao',
        'outbound_fee_multiplier': 'outbound_fee_multiplier'
    }

    def __init__(self, bond_reward_rune=None, total_bond_units=None, total_reserve=None, total_asgard=None, gas_spent_cacao=None, gas_withheld_cacao=None, outbound_fee_multiplier=None):  # noqa: E501
        """NetworkResponse - a model defined in Swagger"""  # noqa: E501
        self._bond_reward_rune = None
        self._total_bond_units = None
        self._total_reserve = None
        self._total_asgard = None
        self._gas_spent_cacao = None
        self._gas_withheld_cacao = None
        self._outbound_fee_multiplier = None
        self.discriminator = None
        self.bond_reward_rune = bond_reward_rune
        self.total_bond_units = total_bond_units
        self.total_reserve = total_reserve
        self.total_asgard = total_asgard
        self.gas_spent_cacao = gas_spent_cacao
        self.gas_withheld_cacao = gas_withheld_cacao
        if outbound_fee_multiplier is not None:
            self.outbound_fee_multiplier = outbound_fee_multiplier

    @property
    def bond_reward_rune(self):
        """Gets the bond_reward_rune of this NetworkResponse.  # noqa: E501

        total amount of cacao awarded to node operators  # noqa: E501

        :return: The bond_reward_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._bond_reward_rune

    @bond_reward_rune.setter
    def bond_reward_rune(self, bond_reward_rune):
        """Sets the bond_reward_rune of this NetworkResponse.

        total amount of cacao awarded to node operators  # noqa: E501

        :param bond_reward_rune: The bond_reward_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if bond_reward_rune is None:
            raise ValueError("Invalid value for `bond_reward_rune`, must not be `None`")  # noqa: E501

        self._bond_reward_rune = bond_reward_rune

    @property
    def total_bond_units(self):
        """Gets the total_bond_units of this NetworkResponse.  # noqa: E501

        total bonded cacao  # noqa: E501

        :return: The total_bond_units of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._total_bond_units

    @total_bond_units.setter
    def total_bond_units(self, total_bond_units):
        """Sets the total_bond_units of this NetworkResponse.

        total bonded cacao  # noqa: E501

        :param total_bond_units: The total_bond_units of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if total_bond_units is None:
            raise ValueError("Invalid value for `total_bond_units`, must not be `None`")  # noqa: E501

        self._total_bond_units = total_bond_units

    @property
    def total_reserve(self):
        """Gets the total_reserve of this NetworkResponse.  # noqa: E501

        total reserve cacao  # noqa: E501

        :return: The total_reserve of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._total_reserve

    @total_reserve.setter
    def total_reserve(self, total_reserve):
        """Sets the total_reserve of this NetworkResponse.

        total reserve cacao  # noqa: E501

        :param total_reserve: The total_reserve of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if total_reserve is None:
            raise ValueError("Invalid value for `total_reserve`, must not be `None`")  # noqa: E501

        self._total_reserve = total_reserve

    @property
    def total_asgard(self):
        """Gets the total_asgard of this NetworkResponse.  # noqa: E501

        total asgard cacao  # noqa: E501

        :return: The total_asgard of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._total_asgard

    @total_asgard.setter
    def total_asgard(self, total_asgard):
        """Sets the total_asgard of this NetworkResponse.

        total asgard cacao  # noqa: E501

        :param total_asgard: The total_asgard of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if total_asgard is None:
            raise ValueError("Invalid value for `total_asgard`, must not be `None`")  # noqa: E501

        self._total_asgard = total_asgard

    @property
    def gas_spent_cacao(self):
        """Gets the gas_spent_cacao of this NetworkResponse.  # noqa: E501

        Sum of the gas the network has spent to send outbounds  # noqa: E501

        :return: The gas_spent_cacao of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._gas_spent_cacao

    @gas_spent_cacao.setter
    def gas_spent_cacao(self, gas_spent_cacao):
        """Sets the gas_spent_cacao of this NetworkResponse.

        Sum of the gas the network has spent to send outbounds  # noqa: E501

        :param gas_spent_cacao: The gas_spent_cacao of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if gas_spent_cacao is None:
            raise ValueError("Invalid value for `gas_spent_cacao`, must not be `None`")  # noqa: E501

        self._gas_spent_cacao = gas_spent_cacao

    @property
    def gas_withheld_cacao(self):
        """Gets the gas_withheld_cacao of this NetworkResponse.  # noqa: E501

        Sum of the gas withheld from users to cover outbound gas  # noqa: E501

        :return: The gas_withheld_cacao of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._gas_withheld_cacao

    @gas_withheld_cacao.setter
    def gas_withheld_cacao(self, gas_withheld_cacao):
        """Sets the gas_withheld_cacao of this NetworkResponse.

        Sum of the gas withheld from users to cover outbound gas  # noqa: E501

        :param gas_withheld_cacao: The gas_withheld_cacao of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if gas_withheld_cacao is None:
            raise ValueError("Invalid value for `gas_withheld_cacao`, must not be `None`")  # noqa: E501

        self._gas_withheld_cacao = gas_withheld_cacao

    @property
    def outbound_fee_multiplier(self):
        """Gets the outbound_fee_multiplier of this NetworkResponse.  # noqa: E501

        Current outbound fee multiplier, in basis points  # noqa: E501

        :return: The outbound_fee_multiplier of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._outbound_fee_multiplier

    @outbound_fee_multiplier.setter
    def outbound_fee_multiplier(self, outbound_fee_multiplier):
        """Sets the outbound_fee_multiplier of this NetworkResponse.

        Current outbound fee multiplier, in basis points  # noqa: E501

        :param outbound_fee_multiplier: The outbound_fee_multiplier of this NetworkResponse.  # noqa: E501
        :type: str
        """

        self._outbound_fee_multiplier = outbound_fee_multiplier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetworkResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_mayanode
from xchainpy2_mayanode.models.keygen_metric1 import KeygenMetric1  # noqa: E501
from xchainpy2_mayanode.rest import ApiException


class TestKeygenMetric1(unittest.TestCase):
    """KeygenMetric1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testKeygenMetric1(self):
        """Test KeygenMetric1"""
        # FIXME: construct object with mandatory attributes with example values
        # model = xchainpy2_mayanode.models.keygen_metric1.KeygenMetric1()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_mayanode
from xchainpy2_mayanode.api.mayanames_api import MayanamesApi  # noqa: E501
from xchainpy2_mayanode.rest import ApiException


class TestMayanamesApi(unittest.TestCase):
    """MayanamesApi unit test stubs"""

    def setUp(self):
        self.api = MayanamesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_mayaname(self):
        """Test case for mayaname

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from xchainpy2_mayanode.api_client import ApiClient


class TSSApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def keysign(self, height, **kwargs):  # noqa: E501
        """keysign  # noqa: E501

        Returns keysign information for the provided height - the height being the first block a tx out item appears in the signed-but-unobserved outbound queue.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keysign(height, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: (required)
        :return: KeysignResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.keysign_with_http_info(height, **kwargs)  # noqa: E501
        else:
            (data) = self.keysign_with_http_info(height, **kwargs)  # noqa: E501
            return data

    def keysign_with_http_info(self, height, **kwargs):  # noqa: E501
        """keysign  # noqa: E501

        Returns keysign information for the provided height - the height being the first block a tx out item appears in the signed-but-unobserved outbound queue.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keysign_with_http_info(height, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: (required)
        :return: KeysignResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method keysign" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'height' is set
        if ('height' not in params or
                params['height'] is None):
            raise ValueError("Missing the required parameter `height` when calling `keysign`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'height' in params:
            path_params['height'] = params['height']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/mayachain/keysign/{height}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='KeysignResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def keysign_pubkey(self, height, pubkey, **kwargs):  # noqa: E501
        """keysign_pubkey  # noqa: E501

        Returns keysign information for the provided height and pubkey - the height being the block at which a tx out item is scheduled to be signed and moved from the scheduled outbound queue to the outbound queue.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keysign_pubkey(height, pubkey, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: (required)
        :param str pubkey: (required)
        :return: KeysignResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.keysign_pubkey_with_http_info(height, pubkey, **kwargs)  # noqa: E501
        else:
            (data) = self.keysign_pubkey_with_http_info(height, pubkey, **kwargs)  # noqa: E501
            return data

    def keysign_pubkey_with_http_info(self, height, pubkey, **kwargs):  # noqa: E501
        """keysign_pubkey  # noqa: E501

        Returns keysign information for the provided height and pubkey - the height being the block at which a tx out item is scheduled to be signed and moved from the scheduled outbound queue to the outbound queue.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keysign_pubkey_with_http_info(height, pubkey, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: (required)
        :param str pubkey: (required)
        :return: KeysignResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height', 'pubkey']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method keysign_pubkey" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'height' is set
        if ('height' not in params or
                params['height'] is None):
            raise ValueError("Missing the required parameter `height` when calling `keysign_pubkey`")  # noqa: E501
        # verify the required parameter 'pubkey' is set
        if ('pubkey' not in params or
                params['pubkey'] is None):
            raise ValueError("Missing the required parameter `pubkey` when calling `keysign_pubkey`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'height' in params:
            path_params['height'] = params['height']  # noqa: E501
        if 'pubkey' in params:
            path_params['pubkey'] = params['pubkey']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/mayachain/keysign/{height}/{pubkey}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='KeysignResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def metrics(self, **kwargs):  # noqa: E501
        """metrics  # noqa: E501

        Returns keygen and keysign metrics for current vaults.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.metrics(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: MetricsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.metrics_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.metrics_with_http_info(**kwargs)  # noqa: E501
            return data

    def metrics_with_http_info(self, **kwargs):  # noqa: E501
        """metrics  # noqa: E501

        Returns keygen and keysign metrics for current vaults.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.metrics_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: MetricsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method metrics" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/mayachain/metrics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MetricsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def metrics_keygen(self, pubkey, **kwargs):  # noqa: E501
        """metrics_keygen  # noqa: E501

        Returns keygen metrics for the provided vault pubkey.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.metrics_keygen(pubkey, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pubkey: (required)
        :param int height: optional block height, defaults to current tip
        :return: list[KeygenMetric1]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.metrics_keygen_with_http_info(pubkey, **kwargs)  # noqa: E501
        else:
            (data) = self.metrics_keygen_with_http_info(pubkey, **kwargs)  # noqa: E501
            return data

    def metrics_keygen_with_http_info(self, pubkey, **kwargs):  # noqa: E501
        """metrics_keygen  # noqa: E501

        Returns keygen metrics for the provided vault pubkey.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.metrics_keygen_with_http_info(pubkey, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pubkey: (required)
        :param int height: optional block height, defaults to current tip
        :return: list[KeygenMetric1]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pubkey', 'height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method metrics_keygen" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'pubkey' is set
        if ('pubkey' not in params or
                params['pubkey'] is None):
            raise ValueError("Missing the required parameter `pubkey` when calling `metrics_keygen`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'pubkey' in params:
            path_params['pubkey'] = params['pubkey']  # noqa: E501

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/mayachain/metric/keygen/{pubkey}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[KeygenMetric1]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_mayanode
from xchainpy2_mayanode.api.tss_api import TSSApi  # noqa: E501
from xchainpy2_mayanode.rest import ApiException


class TestTSSApi(unittest.TestCase):
    """TSSApi unit test stubs"""

    def setUp(self):
        self.api = TSSApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_keysign(self):
        """Test case for keysign

        """
        pass

    def test_keysign_pubkey(self):
        """Test case for keysign_pubkey

        """
        pass

    def test_metrics(self):
        """Test case for metrics

        """
        pass

    def test_metrics_keygen(self):
        """Test case for metrics_keygen

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_mayanode
from xchainpy2_mayanode.api.network_api import NetworkApi  # noqa: E501
from xchainpy2_mayanode.rest import ApiException


class TestNetworkApi(unittest.TestCase):
    """NetworkApi unit test stubs"""

    def setUp(self):
        self.api = NetworkApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_ban(self):
        """Test case for ban

        """
        pass

    def test_constants(self):
        """Test case for constants

        """
        pass

    def test_inbound_addresses(self):
        """Test case for inbound_addresses

        """
        pass

    def test_lastblock(self):
        """Test case for lastblock

        """
        pass

    def test_lastblock_chain(self):
        """Test case for lastblock_chain

        """
        pass

    def test_network(self):
        """Test case for network

        """
        pass

    def test_ragnarok(self):
        """Test case for ragnarok

        """
        pass

    def test_version(self):
        """Test case for version

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from xchainpy2_mayanode.api.buckets_api import BucketsApi
from xchainpy2_mayanode.api.health_api import HealthApi
from xchainpy2_mayanode.api.liquidity_providers_api import LiquidityProvidersApi
from xchainpy2_mayanode.api.mayanames_api import MayanamesApi
from xchainpy2_mayanode.api.mimir_api import MimirApi
from xchainpy2_mayanode.api.network_api import NetworkApi
from xchainpy2_mayanode.api.nodes_api import NodesApi
from xchainpy2_mayanode.api.pol_api import POLApi
from xchainpy2_mayanode.api.pools_api import PoolsApi
from xchainpy2_mayanode.api.queue_api import QueueApi
from xchainpy2_mayanode.api.quote_api import QuoteApi
from xchainpy2_mayanode.api.tss_api import TSSApi
from xchainpy2_mayanode.api.transactions_api import TransactionsApi
from xchainpy2_mayanode.api.vaults_api import VaultsApi
# import ApiClient
from xchainpy2_mayanode.api_client import ApiClient
from xchainpy2_mayanode.configuration import Configuration
# import models into sdk package
from xchainpy2_mayanode.models.ban_response import BanResponse
from xchainpy2_mayanode.models.bucket import Bucket
from xchainpy2_mayanode.models.bucket_response import BucketResponse
from xchainpy2_mayanode.models.buckets_response import BucketsResponse
from xchainpy2_mayanode.models.chain_height import ChainHeight
from xchainpy2_mayanode.models.coin import Coin
from xchainpy2_mayanode.models.constants_response import ConstantsResponse
from xchainpy2_mayanode.models.inbound_address import InboundAddress
from xchainpy2_mayanode.models.inbound_addresses_response import InboundAddressesResponse
from xchainpy2_mayanode.models.keygen_metric import KeygenMetric
from xchainpy2_mayanode.models.keygen_metric1 import KeygenMetric1
from xchainpy2_mayanode.models.keygen_metric2 import KeygenMetric2
from xchainpy2_mayanode.models.keygen_metrics_response import KeygenMetricsResponse
from xchainpy2_mayanode.models.keysign_info import KeysignInfo
from xchainpy2_mayanode.models.keysign_metrics import KeysignMetrics
from xchainpy2_mayanode.models.keysign_response import KeysignResponse
from xchainpy2_mayanode.models.lp_bonded_node import LPBondedNode
from xchainpy2_mayanode.models.last_block import LastBlock
from xchainpy2_mayanode.models.last_block_response import LastBlockResponse
from xchainpy2_mayanode.models.liquidity_provider import LiquidityProvider
from xchainpy2_mayanode.models.liquidity_provider_response import LiquidityProviderResponse
from xchainpy2_mayanode.models.mayaname import Mayaname
from xchainpy2_mayanode.models.mayaname1 import Mayaname1
from xchainpy2_mayanode.models.mayaname_alias import MayanameAlias
from xchainpy2_mayanode.models.mayaname_response import MayanameResponse
from xchainpy2_mayanode.models.metrics_response import MetricsResponse
from xchainpy2_mayanode.models.mimir_nodes_response import MimirNodesResponse
from xchainpy2_mayanode.models.mimir_response import MimirResponse
from xchainpy2_mayanode.models.mimir_vote import MimirVote
from xchainpy2_mayanode.models.network_response import NetworkResponse
from xchainpy2_mayanode.models.node import Node
from xchainpy2_mayanode.models.node_bond_provider import NodeBondProvider
from xchainpy2_mayanode.models.node_bond_providers import NodeBondProviders
from xchainpy2_mayanode.models.node_jail import NodeJail
from xchainpy2_mayanode.models.node_keygen_metric import NodeKeygenMetric
from xchainpy2_mayanode.models.node_preflight_status import NodePreflightStatus
from xchainpy2_mayanode.models.node_pub_key_set import NodePubKeySet
from xchainpy2_mayanode.models.node_response import NodeResponse
from xchainpy2_mayanode.models.nodes_response import NodesResponse
from xchainpy2_mayanode.models.observed_tx import ObservedTx
from xchainpy2_mayanode.models.outbound_response import OutboundResponse
from xchainpy2_mayanode.models.pol_response import POLResponse
from xchainpy2_mayanode.models.ping import Ping
from xchainpy2_mayanode.models.pool import Pool
from xchainpy2_mayanode.models.pool_response import PoolResponse
from xchainpy2_mayanode.models.pools_response import PoolsResponse
from xchainpy2_mayanode.models.queue_response import QueueResponse
from xchainpy2_mayanode.models.quote_fees import QuoteFees
from xchainpy2_mayanode.models.quote_saver_deposit_response import QuoteSaverDepositResponse
from xchainpy2_mayanode.models.quote_saver_withdraw_response import QuoteSaverWithdrawResponse
from xchainpy2_mayanode.models.quote_swap_response import QuoteSwapResponse
from xchainpy2_mayanode.models.scheduled_response import ScheduledResponse
from xchainpy2_mayanode.models.tss_keysign_metric import TssKeysignMetric
from xchainpy2_mayanode.models.tss_metric import TssMetric
from xchainpy2_mayanode.models.tx import Tx
from xchainpy2_mayanode.models.tx_out_item import TxOutItem
from xchainpy2_mayanode.models.tx_response import TxResponse
from xchainpy2_mayanode.models.tx_signers_response import TxSignersResponse
from xchainpy2_mayanode.models.vault import Vault
from xchainpy2_mayanode.models.vault_address import VaultAddress
from xchainpy2_mayanode.models.vault_info import VaultInfo
from xchainpy2_mayanode.models.vault_pubkeys_response import VaultPubkeysResponse
from xchainpy2_mayanode.models.vault_response import VaultResponse
from xchainpy2_mayanode.models.vault_router import VaultRouter
from xchainpy2_mayanode.models.vaults_response import VaultsResponse
from xchainpy2_mayanode.models.version_response import VersionResponse



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LiquidityProvider(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'str',
        'cacao_address': 'str',
        'asset_address': 'str',
        'last_add_height': 'int',
        'last_withdraw_height': 'int',
        'units': 'str',
        'pending_cacao': 'str',
        'pending_asset': 'str',
        'pending_tx_id': 'str',
        'cacao_deposit_value': 'str',
        'asset_deposit_value': 'str',
        'node_bond_address': 'str',
        'withdraw_counter': 'str',
        'last_withdraw_counter_height': 'int',
        'bonded_nodes': 'list[LPBondedNode]'
    }

    attribute_map = {
        'asset': 'asset',
        'cacao_address': 'cacao_address',
        'asset_address': 'asset_address',
        'last_add_height': 'last_add_height',
        'last_withdraw_height': 'last_withdraw_height',
        'units': 'units',
        'pending_cacao': 'pending_cacao',
        'pending_asset': 'pending_asset',
        'pending_tx_id': 'pending_tx_Id',
        'cacao_deposit_value': 'cacao_deposit_value',
        'asset_deposit_value': 'asset_deposit_value',
        'node_bond_address': 'node_bond_address',
        'withdraw_counter': 'withdraw_counter',
        'last_withdraw_counter_height': 'last_withdraw_counter_height',
        'bonded_nodes': 'bonded_nodes'
    }

    def __init__(self, asset=None, cacao_address=None, asset_address=None, last_add_height=None, last_withdraw_height=None, units=None, pending_cacao=None, pending_asset=None, pending_tx_id=None, cacao_deposit_value=None, asset_deposit_value=None, node_bond_address=None, withdraw_counter=None, last_withdraw_counter_height=None, bonded_nodes=None):  # noqa: E501
        """LiquidityProvider - a model defined in Swagger"""  # noqa: E501
        self._asset = None
        self._cacao_address = None
        self._asset_address = None
        self._last_add_height = None
        self._last_withdraw_height = None
        self._units = None
        self._pending_cacao = None
        self._pending_asset = None
        self._pending_tx_id = None
        self._cacao_deposit_value = None
        self._asset_deposit_value = None
        self._node_bond_address = None
        self._withdraw_counter = None
        self._last_withdraw_counter_height = None
        self._bonded_nodes = None
        self.discriminator = None
        self.asset = asset
        if cacao_address is not None:
            self.cacao_address = cacao_address
        if asset_address is not None:
            self.asset_address = asset_address
        if last_add_height is not None:
            self.last_add_height = last_add_height
        if last_withdraw_height is not None:
            self.last_withdraw_height = last_withdraw_height
        self.units = units
        self.pending_cacao = pending_cacao
        self.pending_asset = pending_asset
        if pending_tx_id is not None:
            self.pending_tx_id = pending_tx_id
        self.cacao_deposit_value = cacao_deposit_value
        self.asset_deposit_value = asset_deposit_value
        if node_bond_address is not None:
            self.node_bond_address = node_bond_address
        self.withdraw_counter = withdraw_counter
        if last_withdraw_counter_height is not None:
            self.last_withdraw_counter_height = last_withdraw_counter_height
        self.bonded_nodes = bonded_nodes

    @property
    def asset(self):
        """Gets the asset of this LiquidityProvider.  # noqa: E501


        :return: The asset of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this LiquidityProvider.


        :param asset: The asset of this LiquidityProvider.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def cacao_address(self):
        """Gets the cacao_address of this LiquidityProvider.  # noqa: E501


        :return: The cacao_address of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._cacao_address

    @cacao_address.setter
    def cacao_address(self, cacao_address):
        """Sets the cacao_address of this LiquidityProvider.


        :param cacao_address: The cacao_address of this LiquidityProvider.  # noqa: E501
        :type: str
        """

        self._cacao_address = cacao_address

    @property
    def asset_address(self):
        """Gets the asset_address of this LiquidityProvider.  # noqa: E501


        :return: The asset_address of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._asset_address

    @asset_address.setter
    def asset_address(self, asset_address):
        """Sets the asset_address of this LiquidityProvider.


        :param asset_address: The asset_address of this LiquidityProvider.  # noqa: E501
        :type: str
        """

        self._asset_address = asset_address

    @property
    def last_add_height(self):
        """Gets the last_add_height of this LiquidityProvider.  # noqa: E501


        :return: The last_add_height of this LiquidityProvider.  # noqa: E501
        :rtype: int
        """
        return self._last_add_height

    @last_add_height.setter
    def last_add_height(self, last_add_height):
        """Sets the last_add_height of this LiquidityProvider.


        :param last_add_height: The last_add_height of this LiquidityProvider.  # noqa: E501
        :type: int
        """

        self._last_add_height = last_add_height

    @property
    def last_withdraw_height(self):
        """Gets the last_withdraw_height of this LiquidityProvider.  # noqa: E501


        :return: The last_withdraw_height of this LiquidityProvider.  # noqa: E501
        :rtype: int
        """
        return self._last_withdraw_height

    @last_withdraw_height.setter
    def last_withdraw_height(self, last_withdraw_height):
        """Sets the last_withdraw_height of this LiquidityProvider.


        :param last_withdraw_height: The last_withdraw_height of this LiquidityProvider.  # noqa: E501
        :type: int
        """

        self._last_withdraw_height = last_withdraw_height

    @property
    def units(self):
        """Gets the units of this LiquidityProvider.  # noqa: E501


        :return: The units of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this LiquidityProvider.


        :param units: The units of this LiquidityProvider.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    @property
    def pending_cacao(self):
        """Gets the pending_cacao of this LiquidityProvider.  # noqa: E501


        :return: The pending_cacao of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._pending_cacao

    @pending_cacao.setter
    def pending_cacao(self, pending_cacao):
        """Sets the pending_cacao of this LiquidityProvider.


        :param pending_cacao: The pending_cacao of this LiquidityProvider.  # noqa: E501
        :type: str
        """
        if pending_cacao is None:
            raise ValueError("Invalid value for `pending_cacao`, must not be `None`")  # noqa: E501

        self._pending_cacao = pending_cacao

    @property
    def pending_asset(self):
        """Gets the pending_asset of this LiquidityProvider.  # noqa: E501


        :return: The pending_asset of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._pending_asset

    @pending_asset.setter
    def pending_asset(self, pending_asset):
        """Sets the pending_asset of this LiquidityProvider.


        :param pending_asset: The pending_asset of this LiquidityProvider.  # noqa: E501
        :type: str
        """
        if pending_asset is None:
            raise ValueError("Invalid value for `pending_asset`, must not be `None`")  # noqa: E501

        self._pending_asset = pending_asset

    @property
    def pending_tx_id(self):
        """Gets the pending_tx_id of this LiquidityProvider.  # noqa: E501


        :return: The pending_tx_id of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._pending_tx_id

    @pending_tx_id.setter
    def pending_tx_id(self, pending_tx_id):
        """Sets the pending_tx_id of this LiquidityProvider.


        :param pending_tx_id: The pending_tx_id of this LiquidityProvider.  # noqa: E501
        :type: str
        """

        self._pending_tx_id = pending_tx_id

    @property
    def cacao_deposit_value(self):
        """Gets the cacao_deposit_value of this LiquidityProvider.  # noqa: E501


        :return: The cacao_deposit_value of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._cacao_deposit_value

    @cacao_deposit_value.setter
    def cacao_deposit_value(self, cacao_deposit_value):
        """Sets the cacao_deposit_value of this LiquidityProvider.


        :param cacao_deposit_value: The cacao_deposit_value of this LiquidityProvider.  # noqa: E501
        :type: str
        """
        if cacao_deposit_value is None:
            raise ValueError("Invalid value for `cacao_deposit_value`, must not be `None`")  # noqa: E501

        self._cacao_deposit_value = cacao_deposit_value

    @property
    def asset_deposit_value(self):
        """Gets the asset_deposit_value of this LiquidityProvider.  # noqa: E501


        :return: The asset_deposit_value of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._asset_deposit_value

    @asset_deposit_value.setter
    def asset_deposit_value(self, asset_deposit_value):
        """Sets the asset_deposit_value of this LiquidityProvider.


        :param asset_deposit_value: The asset_deposit_value of this LiquidityProvider.  # noqa: E501
        :type: str
        """
        if asset_deposit_value is None:
            raise ValueError("Invalid value for `asset_deposit_value`, must not be `None`")  # noqa: E501

        self._asset_deposit_value = asset_deposit_value

    @property
    def node_bond_address(self):
        """Gets the node_bond_address of this LiquidityProvider.  # noqa: E501


        :return: The node_bond_address of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._node_bond_address

    @node_bond_address.setter
    def node_bond_address(self, node_bond_address):
        """Sets the node_bond_address of this LiquidityProvider.


        :param node_bond_address: The node_bond_address of this LiquidityProvider.  # noqa: E501
        :type: str
        """

        self._node_bond_address = node_bond_address

    @property
    def withdraw_counter(self):
        """Gets the withdraw_counter of this LiquidityProvider.  # noqa: E501


        :return: The withdraw_counter of this LiquidityProvider.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_counter

    @withdraw_counter.setter
    def withdraw_counter(self, withdraw_counter):
        """Sets the withdraw_counter of this LiquidityProvider.


        :param withdraw_counter: The withdraw_counter of this LiquidityProvider.  # noqa: E501
        :type: str
        """
        if withdraw_counter is None:
            raise ValueError("Invalid value for `withdraw_counter`, must not be `None`")  # noqa: E501

        self._withdraw_counter = withdraw_counter

    @property
    def last_withdraw_counter_height(self):
        """Gets the last_withdraw_counter_height of this LiquidityProvider.  # noqa: E501


        :return: The last_withdraw_counter_height of this LiquidityProvider.  # noqa: E501
        :rtype: int
        """
        return self._last_withdraw_counter_height

    @last_withdraw_counter_height.setter
    def last_withdraw_counter_height(self, last_withdraw_counter_height):
        """Sets the last_withdraw_counter_height of this LiquidityProvider.


        :param last_withdraw_counter_height: The last_withdraw_counter_height of this LiquidityProvider.  # noqa: E501
        :type: int
        """

        self._last_withdraw_counter_height = last_withdraw_counter_height

    @property
    def bonded_nodes(self):
        """Gets the bonded_nodes of this LiquidityProvider.  # noqa: E501


        :return: The bonded_nodes of this LiquidityProvider.  # noqa: E501
        :rtype: list[LPBondedNode]
        """
        return self._bonded_nodes

    @bonded_nodes.setter
    def bonded_nodes(self, bonded_nodes):
        """Sets the bonded_nodes of this LiquidityProvider.


        :param bonded_nodes: The bonded_nodes of this LiquidityProvider.  # noqa: E501
        :type: list[LPBondedNode]
        """
        if bonded_nodes is None:
            raise ValueError("Invalid value for `bonded_nodes`, must not be `None`")  # noqa: E501

        self._bonded_nodes = bonded_nodes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LiquidityProvider, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiquidityProvider):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Bucket(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'balance_asset': 'str',
        'asset': 'str',
        'lp_units': 'str',
        'status': 'str'
    }

    attribute_map = {
        'balance_asset': 'balance_asset',
        'asset': 'asset',
        'lp_units': 'LP_units',
        'status': 'status'
    }

    def __init__(self, balance_asset=None, asset=None, lp_units=None, status=None):  # noqa: E501
        """Bucket - a model defined in Swagger"""  # noqa: E501
        self._balance_asset = None
        self._asset = None
        self._lp_units = None
        self._status = None
        self.discriminator = None
        self.balance_asset = balance_asset
        self.asset = asset
        self.lp_units = lp_units
        self.status = status

    @property
    def balance_asset(self):
        """Gets the balance_asset of this Bucket.  # noqa: E501


        :return: The balance_asset of this Bucket.  # noqa: E501
        :rtype: str
        """
        return self._balance_asset

    @balance_asset.setter
    def balance_asset(self, balance_asset):
        """Sets the balance_asset of this Bucket.


        :param balance_asset: The balance_asset of this Bucket.  # noqa: E501
        :type: str
        """
        if balance_asset is None:
            raise ValueError("Invalid value for `balance_asset`, must not be `None`")  # noqa: E501

        self._balance_asset = balance_asset

    @property
    def asset(self):
        """Gets the asset of this Bucket.  # noqa: E501


        :return: The asset of this Bucket.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this Bucket.


        :param asset: The asset of this Bucket.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def lp_units(self):
        """Gets the lp_units of this Bucket.  # noqa: E501

        the total pool liquidity provider units  # noqa: E501

        :return: The lp_units of this Bucket.  # noqa: E501
        :rtype: str
        """
        return self._lp_units

    @lp_units.setter
    def lp_units(self, lp_units):
        """Sets the lp_units of this Bucket.

        the total pool liquidity provider units  # noqa: E501

        :param lp_units: The lp_units of this Bucket.  # noqa: E501
        :type: str
        """
        if lp_units is None:
            raise ValueError("Invalid value for `lp_units`, must not be `None`")  # noqa: E501

        self._lp_units = lp_units

    @property
    def status(self):
        """Gets the status of this Bucket.  # noqa: E501


        :return: The status of this Bucket.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Bucket.


        :param status: The status of this Bucket.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Bucket, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Bucket):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TxOutItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chain': 'str',
        'to_address': 'str',
        'vault_pub_key': 'str',
        'coin': 'Coin',
        'memo': 'str',
        'max_gas': 'list[Coin]',
        'gas_rate': 'int',
        'in_hash': 'str',
        'out_hash': 'str',
        'height': 'int'
    }

    attribute_map = {
        'chain': 'chain',
        'to_address': 'to_address',
        'vault_pub_key': 'vault_pub_key',
        'coin': 'coin',
        'memo': 'memo',
        'max_gas': 'max_gas',
        'gas_rate': 'gas_rate',
        'in_hash': 'in_hash',
        'out_hash': 'out_hash',
        'height': 'height'
    }

    def __init__(self, chain=None, to_address=None, vault_pub_key=None, coin=None, memo=None, max_gas=None, gas_rate=None, in_hash=None, out_hash=None, height=None):  # noqa: E501
        """TxOutItem - a model defined in Swagger"""  # noqa: E501
        self._chain = None
        self._to_address = None
        self._vault_pub_key = None
        self._coin = None
        self._memo = None
        self._max_gas = None
        self._gas_rate = None
        self._in_hash = None
        self._out_hash = None
        self._height = None
        self.discriminator = None
        self.chain = chain
        self.to_address = to_address
        if vault_pub_key is not None:
            self.vault_pub_key = vault_pub_key
        self.coin = coin
        if memo is not None:
            self.memo = memo
        self.max_gas = max_gas
        if gas_rate is not None:
            self.gas_rate = gas_rate
        if in_hash is not None:
            self.in_hash = in_hash
        if out_hash is not None:
            self.out_hash = out_hash
        self.height = height

    @property
    def chain(self):
        """Gets the chain of this TxOutItem.  # noqa: E501


        :return: The chain of this TxOutItem.  # noqa: E501
        :rtype: str
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this TxOutItem.


        :param chain: The chain of this TxOutItem.  # noqa: E501
        :type: str
        """
        if chain is None:
            raise ValueError("Invalid value for `chain`, must not be `None`")  # noqa: E501

        self._chain = chain

    @property
    def to_address(self):
        """Gets the to_address of this TxOutItem.  # noqa: E501


        :return: The to_address of this TxOutItem.  # noqa: E501
        :rtype: str
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """Sets the to_address of this TxOutItem.


        :param to_address: The to_address of this TxOutItem.  # noqa: E501
        :type: str
        """
        if to_address is None:
            raise ValueError("Invalid value for `to_address`, must not be `None`")  # noqa: E501

        self._to_address = to_address

    @property
    def vault_pub_key(self):
        """Gets the vault_pub_key of this TxOutItem.  # noqa: E501


        :return: The vault_pub_key of this TxOutItem.  # noqa: E501
        :rtype: str
        """
        return self._vault_pub_key

    @vault_pub_key.setter
    def vault_pub_key(self, vault_pub_key):
        """Sets the vault_pub_key of this TxOutItem.


        :param vault_pub_key: The vault_pub_key of this TxOutItem.  # noqa: E501
        :type: str
        """

        self._vault_pub_key = vault_pub_key

    @property
    def coin(self):
        """Gets the coin of this TxOutItem.  # noqa: E501


        :return: The coin of this TxOutItem.  # noqa: E501
        :rtype: Coin
        """
        return self._coin

    @coin.setter
    def coin(self, coin):
        """Sets the coin of this TxOutItem.


        :param coin: The coin of this TxOutItem.  # noqa: E501
        :type: Coin
        """
        if coin is None:
            raise ValueError("Invalid value for `coin`, must not be `None`")  # noqa: E501

        self._coin = coin

    @property
    def memo(self):
        """Gets the memo of this TxOutItem.  # noqa: E501


        :return: The memo of this TxOutItem.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this TxOutItem.


        :param memo: The memo of this TxOutItem.  # noqa: E501
        :type: str
        """

        self._memo = memo

    @property
    def max_gas(self):
        """Gets the max_gas of this TxOutItem.  # noqa: E501


        :return: The max_gas of this TxOutItem.  # noqa: E501
        :rtype: list[Coin]
        """
        return self._max_gas

    @max_gas.setter
    def max_gas(self, max_gas):
        """Sets the max_gas of this TxOutItem.


        :param max_gas: The max_gas of this TxOutItem.  # noqa: E501
        :type: list[Coin]
        """
        if max_gas is None:
            raise ValueError("Invalid value for `max_gas`, must not be `None`")  # noqa: E501

        self._max_gas = max_gas

    @property
    def gas_rate(self):
        """Gets the gas_rate of this TxOutItem.  # noqa: E501


        :return: The gas_rate of this TxOutItem.  # noqa: E501
        :rtype: int
        """
        return self._gas_rate

    @gas_rate.setter
    def gas_rate(self, gas_rate):
        """Sets the gas_rate of this TxOutItem.


        :param gas_rate: The gas_rate of this TxOutItem.  # noqa: E501
        :type: int
        """

        self._gas_rate = gas_rate

    @property
    def in_hash(self):
        """Gets the in_hash of this TxOutItem.  # noqa: E501


        :return: The in_hash of this TxOutItem.  # noqa: E501
        :rtype: str
        """
        return self._in_hash

    @in_hash.setter
    def in_hash(self, in_hash):
        """Sets the in_hash of this TxOutItem.


        :param in_hash: The in_hash of this TxOutItem.  # noqa: E501
        :type: str
        """

        self._in_hash = in_hash

    @property
    def out_hash(self):
        """Gets the out_hash of this TxOutItem.  # noqa: E501


        :return: The out_hash of this TxOutItem.  # noqa: E501
        :rtype: str
        """
        return self._out_hash

    @out_hash.setter
    def out_hash(self, out_hash):
        """Sets the out_hash of this TxOutItem.


        :param out_hash: The out_hash of this TxOutItem.  # noqa: E501
        :type: str
        """

        self._out_hash = out_hash

    @property
    def height(self):
        """Gets the height of this TxOutItem.  # noqa: E501


        :return: The height of this TxOutItem.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this TxOutItem.


        :param height: The height of this TxOutItem.  # noqa: E501
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TxOutItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TxOutItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Node(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_address': 'str',
        'status': 'str',
        'pub_key_set': 'NodePubKeySet',
        'aztec_address': 'str',
        'validator_cons_pub_key': 'str',
        'peer_id': 'str',
        'bond': 'str',
        'reward': 'str',
        'active_block_height': 'int',
        'bond_address': 'str',
        'status_since': 'int',
        'signer_membership': 'list[str]',
        'requested_to_leave': 'bool',
        'forced_to_leave': 'bool',
        'leave_height': 'int',
        'ip_address': 'str',
        'version': 'str',
        'slash_points': 'int',
        'jail': 'NodeJail',
        'observe_chains': 'list[ChainHeight]',
        'preflight_status': 'NodePreflightStatus',
        'bond_providers': 'NodeBondProviders'
    }

    attribute_map = {
        'node_address': 'node_address',
        'status': 'status',
        'pub_key_set': 'pub_key_set',
        'aztec_address': 'aztec_address',
        'validator_cons_pub_key': 'validator_cons_pub_key',
        'peer_id': 'peer_id',
        'bond': 'bond',
        'reward': 'reward',
        'active_block_height': 'active_block_height',
        'bond_address': 'bond_address',
        'status_since': 'status_since',
        'signer_membership': 'signer_membership',
        'requested_to_leave': 'requested_to_leave',
        'forced_to_leave': 'forced_to_leave',
        'leave_height': 'leave_height',
        'ip_address': 'ip_address',
        'version': 'version',
        'slash_points': 'slash_points',
        'jail': 'jail',
        'observe_chains': 'observe_chains',
        'preflight_status': 'preflight_status',
        'bond_providers': 'bond_providers'
    }

    def __init__(self, node_address=None, status=None, pub_key_set=None, aztec_address=None, validator_cons_pub_key=None, peer_id=None, bond=None, reward=None, active_block_height=None, bond_address=None, status_since=None, signer_membership=None, requested_to_leave=None, forced_to_leave=None, leave_height=None, ip_address=None, version=None, slash_points=None, jail=None, observe_chains=None, preflight_status=None, bond_providers=None):  # noqa: E501
        """Node - a model defined in Swagger"""  # noqa: E501
        self._node_address = None
        self._status = None
        self._pub_key_set = None
        self._aztec_address = None
        self._validator_cons_pub_key = None
        self._peer_id = None
        self._bond = None
        self._reward = None
        self._active_block_height = None
        self._bond_address = None
        self._status_since = None
        self._signer_membership = None
        self._requested_to_leave = None
        self._forced_to_leave = None
        self._leave_height = None
        self._ip_address = None
        self._version = None
        self._slash_points = None
        self._jail = None
        self._observe_chains = None
        self._preflight_status = None
        self._bond_providers = None
        self.discriminator = None
        self.node_address = node_address
        self.status = status
        self.pub_key_set = pub_key_set
        self.aztec_address = aztec_address
        self.validator_cons_pub_key = validator_cons_pub_key
        self.peer_id = peer_id
        self.bond = bond
        self.reward = reward
        self.active_block_height = active_block_height
        self.bond_address = bond_address
        self.status_since = status_since
        self.signer_membership = signer_membership
        self.requested_to_leave = requested_to_leave
        self.forced_to_leave = forced_to_leave
        self.leave_height = leave_height
        self.ip_address = ip_address
        self.version = version
        self.slash_points = slash_points
        self.jail = jail
        self.observe_chains = observe_chains
        self.preflight_status = preflight_status
        self.bond_providers = bond_providers

    @property
    def node_address(self):
        """Gets the node_address of this Node.  # noqa: E501


        :return: The node_address of this Node.  # noqa: E501
        :rtype: str
        """
        return self._node_address

    @node_address.setter
    def node_address(self, node_address):
        """Sets the node_address of this Node.


        :param node_address: The node_address of this Node.  # noqa: E501
        :type: str
        """
        if node_address is None:
            raise ValueError("Invalid value for `node_address`, must not be `None`")  # noqa: E501

        self._node_address = node_address

    @property
    def status(self):
        """Gets the status of this Node.  # noqa: E501


        :return: The status of this Node.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Node.


        :param status: The status of this Node.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["Active", "Whitelisted", "Standby", "Disabled"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def pub_key_set(self):
        """Gets the pub_key_set of this Node.  # noqa: E501


        :return: The pub_key_set of this Node.  # noqa: E501
        :rtype: NodePubKeySet
        """
        return self._pub_key_set

    @pub_key_set.setter
    def pub_key_set(self, pub_key_set):
        """Sets the pub_key_set of this Node.


        :param pub_key_set: The pub_key_set of this Node.  # noqa: E501
        :type: NodePubKeySet
        """
        if pub_key_set is None:
            raise ValueError("Invalid value for `pub_key_set`, must not be `None`")  # noqa: E501

        self._pub_key_set = pub_key_set

    @property
    def aztec_address(self):
        """Gets the aztec_address of this Node.  # noqa: E501


        :return: The aztec_address of this Node.  # noqa: E501
        :rtype: str
        """
        return self._aztec_address

    @aztec_address.setter
    def aztec_address(self, aztec_address):
        """Sets the aztec_address of this Node.


        :param aztec_address: The aztec_address of this Node.  # noqa: E501
        :type: str
        """
        if aztec_address is None:
            raise ValueError("Invalid value for `aztec_address`, must not be `None`")  # noqa: E501

        self._aztec_address = aztec_address

    @property
    def validator_cons_pub_key(self):
        """Gets the validator_cons_pub_key of this Node.  # noqa: E501

        the consensus pub key for the node  # noqa: E501

        :return: The validator_cons_pub_key of this Node.  # noqa: E501
        :rtype: str
        """
        return self._validator_cons_pub_key

    @validator_cons_pub_key.setter
    def validator_cons_pub_key(self, validator_cons_pub_key):
        """Sets the validator_cons_pub_key of this Node.

        the consensus pub key for the node  # noqa: E501

        :param validator_cons_pub_key: The validator_cons_pub_key of this Node.  # noqa: E501
        :type: str
        """
        if validator_cons_pub_key is None:
            raise ValueError("Invalid value for `validator_cons_pub_key`, must not be `None`")  # noqa: E501

        self._validator_cons_pub_key = validator_cons_pub_key

    @property
    def peer_id(self):
        """Gets the peer_id of this Node.  # noqa: E501

        the P2PID (:6040/p2pid endpoint) of the node  # noqa: E501

        :return: The peer_id of this Node.  # noqa: E501
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """Sets the peer_id of this Node.

        the P2PID (:6040/p2pid endpoint) of the node  # noqa: E501

        :param peer_id: The peer_id of this Node.  # noqa: E501
        :type: str
        """
        if peer_id is None:
            raise ValueError("Invalid value for `peer_id`, must not be `None`")  # noqa: E501

        self._peer_id = peer_id

    @property
    def bond(self):
        """Gets the bond of this Node.  # noqa: E501

        current node bond  # noqa: E501

        :return: The bond of this Node.  # noqa: E501
        :rtype: str
        """
        return self._bond

    @bond.setter
    def bond(self, bond):
        """Sets the bond of this Node.

        current node bond  # noqa: E501

        :param bond: The bond of this Node.  # noqa: E501
        :type: str
        """
        if bond is None:
            raise ValueError("Invalid value for `bond`, must not be `None`")  # noqa: E501

        self._bond = bond

    @property
    def reward(self):
        """Gets the reward of this Node.  # noqa: E501


        :return: The reward of this Node.  # noqa: E501
        :rtype: str
        """
        return self._reward

    @reward.setter
    def reward(self, reward):
        """Sets the reward of this Node.


        :param reward: The reward of this Node.  # noqa: E501
        :type: str
        """
        if reward is None:
            raise ValueError("Invalid value for `reward`, must not be `None`")  # noqa: E501

        self._reward = reward

    @property
    def active_block_height(self):
        """Gets the active_block_height of this Node.  # noqa: E501

        the block height at which the node became active  # noqa: E501

        :return: The active_block_height of this Node.  # noqa: E501
        :rtype: int
        """
        return self._active_block_height

    @active_block_height.setter
    def active_block_height(self, active_block_height):
        """Sets the active_block_height of this Node.

        the block height at which the node became active  # noqa: E501

        :param active_block_height: The active_block_height of this Node.  # noqa: E501
        :type: int
        """
        if active_block_height is None:
            raise ValueError("Invalid value for `active_block_height`, must not be `None`")  # noqa: E501

        self._active_block_height = active_block_height

    @property
    def bond_address(self):
        """Gets the bond_address of this Node.  # noqa: E501


        :return: The bond_address of this Node.  # noqa: E501
        :rtype: str
        """
        return self._bond_address

    @bond_address.setter
    def bond_address(self, bond_address):
        """Sets the bond_address of this Node.


        :param bond_address: The bond_address of this Node.  # noqa: E501
        :type: str
        """
        if bond_address is None:
            raise ValueError("Invalid value for `bond_address`, must not be `None`")  # noqa: E501

        self._bond_address = bond_address

    @property
    def status_since(self):
        """Gets the status_since of this Node.  # noqa: E501

        the block height of the current provided information for the node  # noqa: E501

        :return: The status_since of this Node.  # noqa: E501
        :rtype: int
        """
        return self._status_since

    @status_since.setter
    def status_since(self, status_since):
        """Sets the status_since of this Node.

        the block height of the current provided information for the node  # noqa: E501

        :param status_since: The status_since of this Node.  # noqa: E501
        :type: int
        """
        if status_since is None:
            raise ValueError("Invalid value for `status_since`, must not be `None`")  # noqa: E501

        self._status_since = status_since

    @property
    def signer_membership(self):
        """Gets the signer_membership of this Node.  # noqa: E501

        the set of vault public keys of which the node is a member  # noqa: E501

        :return: The signer_membership of this Node.  # noqa: E501
        :rtype: list[str]
        """
        return self._signer_membership

    @signer_membership.setter
    def signer_membership(self, signer_membership):
        """Sets the signer_membership of this Node.

        the set of vault public keys of which the node is a member  # noqa: E501

        :param signer_membership: The signer_membership of this Node.  # noqa: E501
        :type: list[str]
        """
        if signer_membership is None:
            raise ValueError("Invalid value for `signer_membership`, must not be `None`")  # noqa: E501

        self._signer_membership = signer_membership

    @property
    def requested_to_leave(self):
        """Gets the requested_to_leave of this Node.  # noqa: E501


        :return: The requested_to_leave of this Node.  # noqa: E501
        :rtype: bool
        """
        return self._requested_to_leave

    @requested_to_leave.setter
    def requested_to_leave(self, requested_to_leave):
        """Sets the requested_to_leave of this Node.


        :param requested_to_leave: The requested_to_leave of this Node.  # noqa: E501
        :type: bool
        """
        if requested_to_leave is None:
            raise ValueError("Invalid value for `requested_to_leave`, must not be `None`")  # noqa: E501

        self._requested_to_leave = requested_to_leave

    @property
    def forced_to_leave(self):
        """Gets the forced_to_leave of this Node.  # noqa: E501

        indicates whether the node has been forced to leave by the network, typically via ban  # noqa: E501

        :return: The forced_to_leave of this Node.  # noqa: E501
        :rtype: bool
        """
        return self._forced_to_leave

    @forced_to_leave.setter
    def forced_to_leave(self, forced_to_leave):
        """Sets the forced_to_leave of this Node.

        indicates whether the node has been forced to leave by the network, typically via ban  # noqa: E501

        :param forced_to_leave: The forced_to_leave of this Node.  # noqa: E501
        :type: bool
        """
        if forced_to_leave is None:
            raise ValueError("Invalid value for `forced_to_leave`, must not be `None`")  # noqa: E501

        self._forced_to_leave = forced_to_leave

    @property
    def leave_height(self):
        """Gets the leave_height of this Node.  # noqa: E501


        :return: The leave_height of this Node.  # noqa: E501
        :rtype: int
        """
        return self._leave_height

    @leave_height.setter
    def leave_height(self, leave_height):
        """Sets the leave_height of this Node.


        :param leave_height: The leave_height of this Node.  # noqa: E501
        :type: int
        """
        if leave_height is None:
            raise ValueError("Invalid value for `leave_height`, must not be `None`")  # noqa: E501

        self._leave_height = leave_height

    @property
    def ip_address(self):
        """Gets the ip_address of this Node.  # noqa: E501


        :return: The ip_address of this Node.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this Node.


        :param ip_address: The ip_address of this Node.  # noqa: E501
        :type: str
        """
        if ip_address is None:
            raise ValueError("Invalid value for `ip_address`, must not be `None`")  # noqa: E501

        self._ip_address = ip_address

    @property
    def version(self):
        """Gets the version of this Node.  # noqa: E501

        the currently set version of the node  # noqa: E501

        :return: The version of this Node.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Node.

        the currently set version of the node  # noqa: E501

        :param version: The version of this Node.  # noqa: E501
        :type: str
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def slash_points(self):
        """Gets the slash_points of this Node.  # noqa: E501

        the accumlated slash points, reset at churn but excessive slash points may carry over  # noqa: E501

        :return: The slash_points of this Node.  # noqa: E501
        :rtype: int
        """
        return self._slash_points

    @slash_points.setter
    def slash_points(self, slash_points):
        """Sets the slash_points of this Node.

        the accumlated slash points, reset at churn but excessive slash points may carry over  # noqa: E501

        :param slash_points: The slash_points of this Node.  # noqa: E501
        :type: int
        """
        if slash_points is None:
            raise ValueError("Invalid value for `slash_points`, must not be `None`")  # noqa: E501

        self._slash_points = slash_points

    @property
    def jail(self):
        """Gets the jail of this Node.  # noqa: E501


        :return: The jail of this Node.  # noqa: E501
        :rtype: NodeJail
        """
        return self._jail

    @jail.setter
    def jail(self, jail):
        """Sets the jail of this Node.


        :param jail: The jail of this Node.  # noqa: E501
        :type: NodeJail
        """
        if jail is None:
            raise ValueError("Invalid value for `jail`, must not be `None`")  # noqa: E501

        self._jail = jail

    @property
    def observe_chains(self):
        """Gets the observe_chains of this Node.  # noqa: E501

        the last observed heights for all chain by the node  # noqa: E501

        :return: The observe_chains of this Node.  # noqa: E501
        :rtype: list[ChainHeight]
        """
        return self._observe_chains

    @observe_chains.setter
    def observe_chains(self, observe_chains):
        """Sets the observe_chains of this Node.

        the last observed heights for all chain by the node  # noqa: E501

        :param observe_chains: The observe_chains of this Node.  # noqa: E501
        :type: list[ChainHeight]
        """
        if observe_chains is None:
            raise ValueError("Invalid value for `observe_chains`, must not be `None`")  # noqa: E501

        self._observe_chains = observe_chains

    @property
    def preflight_status(self):
        """Gets the preflight_status of this Node.  # noqa: E501


        :return: The preflight_status of this Node.  # noqa: E501
        :rtype: NodePreflightStatus
        """
        return self._preflight_status

    @preflight_status.setter
    def preflight_status(self, preflight_status):
        """Sets the preflight_status of this Node.


        :param preflight_status: The preflight_status of this Node.  # noqa: E501
        :type: NodePreflightStatus
        """
        if preflight_status is None:
            raise ValueError("Invalid value for `preflight_status`, must not be `None`")  # noqa: E501

        self._preflight_status = preflight_status

    @property
    def bond_providers(self):
        """Gets the bond_providers of this Node.  # noqa: E501


        :return: The bond_providers of this Node.  # noqa: E501
        :rtype: NodeBondProviders
        """
        return self._bond_providers

    @bond_providers.setter
    def bond_providers(self, bond_providers):
        """Sets the bond_providers of this Node.


        :param bond_providers: The bond_providers of this Node.  # noqa: E501
        :type: NodeBondProviders
        """
        if bond_providers is None:
            raise ValueError("Invalid value for `bond_providers`, must not be `None`")  # noqa: E501

        self._bond_providers = bond_providers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Node, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Node):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from xchainpy2_mayanode.api.buckets_api import BucketsApi
from xchainpy2_mayanode.api.health_api import HealthApi
from xchainpy2_mayanode.api.liquidity_providers_api import LiquidityProvidersApi
from xchainpy2_mayanode.api.mayanames_api import MayanamesApi
from xchainpy2_mayanode.api.mimir_api import MimirApi
from xchainpy2_mayanode.api.network_api import NetworkApi
from xchainpy2_mayanode.api.nodes_api import NodesApi
from xchainpy2_mayanode.api.pol_api import POLApi
from xchainpy2_mayanode.api.pools_api import PoolsApi
from xchainpy2_mayanode.api.queue_api import QueueApi
from xchainpy2_mayanode.api.quote_api import QuoteApi
from xchainpy2_mayanode.api.tss_api import TSSApi
from xchainpy2_mayanode.api.transactions_api import TransactionsApi
from xchainpy2_mayanode.api.vaults_api import VaultsApi



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ObservedTx(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tx': 'Tx',
        'status': 'str',
        'out_hashes': 'list[str]',
        'block_height': 'int',
        'signers': 'list[str]',
        'observed_pub_key': 'str',
        'keysign_ms': 'int',
        'finalise_height': 'int',
        'aggregator': 'str',
        'aggregator_target': 'str',
        'aggregator_target_limit': 'str'
    }

    attribute_map = {
        'tx': 'tx',
        'status': 'status',
        'out_hashes': 'out_hashes',
        'block_height': 'block_height',
        'signers': 'signers',
        'observed_pub_key': 'observed_pub_key',
        'keysign_ms': 'keysign_ms',
        'finalise_height': 'finalise_height',
        'aggregator': 'aggregator',
        'aggregator_target': 'aggregator_target',
        'aggregator_target_limit': 'aggregator_target_limit'
    }

    def __init__(self, tx=None, status=None, out_hashes=None, block_height=None, signers=None, observed_pub_key=None, keysign_ms=None, finalise_height=None, aggregator=None, aggregator_target=None, aggregator_target_limit=None):  # noqa: E501
        """ObservedTx - a model defined in Swagger"""  # noqa: E501
        self._tx = None
        self._status = None
        self._out_hashes = None
        self._block_height = None
        self._signers = None
        self._observed_pub_key = None
        self._keysign_ms = None
        self._finalise_height = None
        self._aggregator = None
        self._aggregator_target = None
        self._aggregator_target_limit = None
        self.discriminator = None
        self.tx = tx
        if status is not None:
            self.status = status
        if out_hashes is not None:
            self.out_hashes = out_hashes
        if block_height is not None:
            self.block_height = block_height
        if signers is not None:
            self.signers = signers
        if observed_pub_key is not None:
            self.observed_pub_key = observed_pub_key
        if keysign_ms is not None:
            self.keysign_ms = keysign_ms
        if finalise_height is not None:
            self.finalise_height = finalise_height
        if aggregator is not None:
            self.aggregator = aggregator
        if aggregator_target is not None:
            self.aggregator_target = aggregator_target
        if aggregator_target_limit is not None:
            self.aggregator_target_limit = aggregator_target_limit

    @property
    def tx(self):
        """Gets the tx of this ObservedTx.  # noqa: E501


        :return: The tx of this ObservedTx.  # noqa: E501
        :rtype: Tx
        """
        return self._tx

    @tx.setter
    def tx(self, tx):
        """Sets the tx of this ObservedTx.


        :param tx: The tx of this ObservedTx.  # noqa: E501
        :type: Tx
        """
        if tx is None:
            raise ValueError("Invalid value for `tx`, must not be `None`")  # noqa: E501

        self._tx = tx

    @property
    def status(self):
        """Gets the status of this ObservedTx.  # noqa: E501


        :return: The status of this ObservedTx.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ObservedTx.


        :param status: The status of this ObservedTx.  # noqa: E501
        :type: str
        """
        allowed_values = ["done", "incomplete"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def out_hashes(self):
        """Gets the out_hashes of this ObservedTx.  # noqa: E501


        :return: The out_hashes of this ObservedTx.  # noqa: E501
        :rtype: list[str]
        """
        return self._out_hashes

    @out_hashes.setter
    def out_hashes(self, out_hashes):
        """Sets the out_hashes of this ObservedTx.


        :param out_hashes: The out_hashes of this ObservedTx.  # noqa: E501
        :type: list[str]
        """

        self._out_hashes = out_hashes

    @property
    def block_height(self):
        """Gets the block_height of this ObservedTx.  # noqa: E501

        the block height of the observed transaction on the source chain, not provided if chain is MAYA  # noqa: E501

        :return: The block_height of this ObservedTx.  # noqa: E501
        :rtype: int
        """
        return self._block_height

    @block_height.setter
    def block_height(self, block_height):
        """Sets the block_height of this ObservedTx.

        the block height of the observed transaction on the source chain, not provided if chain is MAYA  # noqa: E501

        :param block_height: The block_height of this ObservedTx.  # noqa: E501
        :type: int
        """

        self._block_height = block_height

    @property
    def signers(self):
        """Gets the signers of this ObservedTx.  # noqa: E501


        :return: The signers of this ObservedTx.  # noqa: E501
        :rtype: list[str]
        """
        return self._signers

    @signers.setter
    def signers(self, signers):
        """Sets the signers of this ObservedTx.


        :param signers: The signers of this ObservedTx.  # noqa: E501
        :type: list[str]
        """

        self._signers = signers

    @property
    def observed_pub_key(self):
        """Gets the observed_pub_key of this ObservedTx.  # noqa: E501


        :return: The observed_pub_key of this ObservedTx.  # noqa: E501
        :rtype: str
        """
        return self._observed_pub_key

    @observed_pub_key.setter
    def observed_pub_key(self, observed_pub_key):
        """Sets the observed_pub_key of this ObservedTx.


        :param observed_pub_key: The observed_pub_key of this ObservedTx.  # noqa: E501
        :type: str
        """

        self._observed_pub_key = observed_pub_key

    @property
    def keysign_ms(self):
        """Gets the keysign_ms of this ObservedTx.  # noqa: E501


        :return: The keysign_ms of this ObservedTx.  # noqa: E501
        :rtype: int
        """
        return self._keysign_ms

    @keysign_ms.setter
    def keysign_ms(self, keysign_ms):
        """Sets the keysign_ms of this ObservedTx.


        :param keysign_ms: The keysign_ms of this ObservedTx.  # noqa: E501
        :type: int
        """

        self._keysign_ms = keysign_ms

    @property
    def finalise_height(self):
        """Gets the finalise_height of this ObservedTx.  # noqa: E501

        the finalised height of the observed transaction on the source chain, not provided if chain is MAYA  # noqa: E501

        :return: The finalise_height of this ObservedTx.  # noqa: E501
        :rtype: int
        """
        return self._finalise_height

    @finalise_height.setter
    def finalise_height(self, finalise_height):
        """Sets the finalise_height of this ObservedTx.

        the finalised height of the observed transaction on the source chain, not provided if chain is MAYA  # noqa: E501

        :param finalise_height: The finalise_height of this ObservedTx.  # noqa: E501
        :type: int
        """

        self._finalise_height = finalise_height

    @property
    def aggregator(self):
        """Gets the aggregator of this ObservedTx.  # noqa: E501

        the outbound aggregator to use, will also match a suffix  # noqa: E501

        :return: The aggregator of this ObservedTx.  # noqa: E501
        :rtype: str
        """
        return self._aggregator

    @aggregator.setter
    def aggregator(self, aggregator):
        """Sets the aggregator of this ObservedTx.

        the outbound aggregator to use, will also match a suffix  # noqa: E501

        :param aggregator: The aggregator of this ObservedTx.  # noqa: E501
        :type: str
        """

        self._aggregator = aggregator

    @property
    def aggregator_target(self):
        """Gets the aggregator_target of this ObservedTx.  # noqa: E501

        the aggregator target asset provided to transferOutAndCall  # noqa: E501

        :return: The aggregator_target of this ObservedTx.  # noqa: E501
        :rtype: str
        """
        return self._aggregator_target

    @aggregator_target.setter
    def aggregator_target(self, aggregator_target):
        """Sets the aggregator_target of this ObservedTx.

        the aggregator target asset provided to transferOutAndCall  # noqa: E501

        :param aggregator_target: The aggregator_target of this ObservedTx.  # noqa: E501
        :type: str
        """

        self._aggregator_target = aggregator_target

    @property
    def aggregator_target_limit(self):
        """Gets the aggregator_target_limit of this ObservedTx.  # noqa: E501

        the aggregator target asset limit provided to transferOutAndCall  # noqa: E501

        :return: The aggregator_target_limit of this ObservedTx.  # noqa: E501
        :rtype: str
        """
        return self._aggregator_target_limit

    @aggregator_target_limit.setter
    def aggregator_target_limit(self, aggregator_target_limit):
        """Sets the aggregator_target_limit of this ObservedTx.

        the aggregator target asset limit provided to transferOutAndCall  # noqa: E501

        :param aggregator_target_limit: The aggregator_target_limit of this ObservedTx.  # noqa: E501
        :type: str
        """

        self._aggregator_target_limit = aggregator_target_limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ObservedTx, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObservedTx):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_mayanode
from xchainpy2_mayanode.api.mimir_api import MimirApi  # noqa: E501
from xchainpy2_mayanode.rest import ApiException


class TestMimirApi(unittest.TestCase):
    """MimirApi unit test stubs"""

    def setUp(self):
        self.api = MimirApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_mimir(self):
        """Test case for mimir

        """
        pass

    def test_mimir_admin(self):
        """Test case for mimir_admin

        """
        pass

    def test_mimir_key(self):
        """Test case for mimir_key

        """
        pass

    def test_mimir_node(self):
        """Test case for mimir_node

        """
        pass

    def test_mimir_nodes(self):
        """Test case for mimir_nodes

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "xchainpy2-mayanode"
VERSION = "1.107.3"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]
REQUIRES.append("aiohttp")


def load_description():
    """
    In setup call you do:
    long_description=load_description(),
    long_description_content_type="text/markdown",
    :return: text
    """
    from pathlib import Path
    this_directory = Path(__file__).parent
    long_description = (this_directory / "README.md").read_text()
    return long_description


setup(
    name=NAME,
    version=VERSION,
    description="Mayanode API",
    author_email="devs@mayachain.org",
    url="",
    keywords=["Swagger", "Mayanode API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=load_description(),
    long_description_content_type="text/markdown",
)



# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class POLResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cacao_deposited': 'str',
        'cacao_withdrawn': 'str',
        'value': 'str',
        'pnl': 'str',
        'current_deposit': 'str'
    }

    attribute_map = {
        'cacao_deposited': 'cacao_deposited',
        'cacao_withdrawn': 'cacao_withdrawn',
        'value': 'value',
        'pnl': 'pnl',
        'current_deposit': 'current_deposit'
    }

    def __init__(self, cacao_deposited=None, cacao_withdrawn=None, value=None, pnl=None, current_deposit=None):  # noqa: E501
        """POLResponse - a model defined in Swagger"""  # noqa: E501
        self._cacao_deposited = None
        self._cacao_withdrawn = None
        self._value = None
        self._pnl = None
        self._current_deposit = None
        self.discriminator = None
        self.cacao_deposited = cacao_deposited
        self.cacao_withdrawn = cacao_withdrawn
        self.value = value
        self.pnl = pnl
        self.current_deposit = current_deposit

    @property
    def cacao_deposited(self):
        """Gets the cacao_deposited of this POLResponse.  # noqa: E501

        total amount of RUNE deposited into the pools  # noqa: E501

        :return: The cacao_deposited of this POLResponse.  # noqa: E501
        :rtype: str
        """
        return self._cacao_deposited

    @cacao_deposited.setter
    def cacao_deposited(self, cacao_deposited):
        """Sets the cacao_deposited of this POLResponse.

        total amount of RUNE deposited into the pools  # noqa: E501

        :param cacao_deposited: The cacao_deposited of this POLResponse.  # noqa: E501
        :type: str
        """
        if cacao_deposited is None:
            raise ValueError("Invalid value for `cacao_deposited`, must not be `None`")  # noqa: E501

        self._cacao_deposited = cacao_deposited

    @property
    def cacao_withdrawn(self):
        """Gets the cacao_withdrawn of this POLResponse.  # noqa: E501

        total amount of RUNE withdrawn from the pools  # noqa: E501

        :return: The cacao_withdrawn of this POLResponse.  # noqa: E501
        :rtype: str
        """
        return self._cacao_withdrawn

    @cacao_withdrawn.setter
    def cacao_withdrawn(self, cacao_withdrawn):
        """Sets the cacao_withdrawn of this POLResponse.

        total amount of RUNE withdrawn from the pools  # noqa: E501

        :param cacao_withdrawn: The cacao_withdrawn of this POLResponse.  # noqa: E501
        :type: str
        """
        if cacao_withdrawn is None:
            raise ValueError("Invalid value for `cacao_withdrawn`, must not be `None`")  # noqa: E501

        self._cacao_withdrawn = cacao_withdrawn

    @property
    def value(self):
        """Gets the value of this POLResponse.  # noqa: E501

        total value of protocol's LP position in RUNE value  # noqa: E501

        :return: The value of this POLResponse.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this POLResponse.

        total value of protocol's LP position in RUNE value  # noqa: E501

        :param value: The value of this POLResponse.  # noqa: E501
        :type: str
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def pnl(self):
        """Gets the pnl of this POLResponse.  # noqa: E501

        profit and loss of protocol owned liquidity  # noqa: E501

        :return: The pnl of this POLResponse.  # noqa: E501
        :rtype: str
        """
        return self._pnl

    @pnl.setter
    def pnl(self, pnl):
        """Sets the pnl of this POLResponse.

        profit and loss of protocol owned liquidity  # noqa: E501

        :param pnl: The pnl of this POLResponse.  # noqa: E501
        :type: str
        """
        if pnl is None:
            raise ValueError("Invalid value for `pnl`, must not be `None`")  # noqa: E501

        self._pnl = pnl

    @property
    def current_deposit(self):
        """Gets the current_deposit of this POLResponse.  # noqa: E501

        current amount of rune deposited  # noqa: E501

        :return: The current_deposit of this POLResponse.  # noqa: E501
        :rtype: str
        """
        return self._current_deposit

    @current_deposit.setter
    def current_deposit(self, current_deposit):
        """Sets the current_deposit of this POLResponse.

        current amount of rune deposited  # noqa: E501

        :param current_deposit: The current_deposit of this POLResponse.  # noqa: E501
        :type: str
        """
        if current_deposit is None:
            raise ValueError("Invalid value for `current_deposit`, must not be `None`")  # noqa: E501

        self._current_deposit = current_deposit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(POLResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, POLResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
